pub struct OperatorContext { /* private fields */ }Expand description
Operator context providing access to state and other resources
Implementations
Sourceimpl OperatorContext
impl OperatorContext
Sourcepub fn new(ctx: *mut FFIContext) -> Self
pub fn new(ctx: *mut FFIContext) -> Self
Create a new operator context from an FFI context pointer
Safety
The caller must ensure ctx is non-null and valid for the lifetime of this context
Sourcepub fn operator_id(&self) -> FlowNodeId
pub fn operator_id(&self) -> FlowNodeId
Get the operator ID from the FFI context
Sourcepub fn get_or_create_row_number(
&mut self,
key: &EncodedKey,
) -> Result<(RowNumber, bool)>
pub fn get_or_create_row_number( &mut self, key: &EncodedKey, ) -> Result<(RowNumber, bool)>
Get or create a row number for a given key
This is a convenience method that creates a RowNumberProvider and
delegates to its get_or_create_row_number method.
Returns (RowNumber, is_new) where is_new indicates if this is
a newly created row number.